% Function to plot the movie of motion of PDF's
clear all

[a,  b, m, h, x, y, Nt, t, dt, nu,eta, rho,scale] = parameters(1);
global pi1 pf1 s1
global pi2 pf2 s2


% Total number of grid points along each direction.
Nx = m+1;

% Starting point of the trajectory.
ip1 = traj1(t(1),1);
ip2 = traj2(t(1),1); 

for i = 2:Nx-1
    for j = 2:Nx-1
        rho1(i,j) = exp((-(x(i)-ip1(1))^2-(y(j)-ip1(2))^2)/0.5);
        rho2(i,j) = exp((-(x(i)-ip2(1))^2-(y(j)-ip2(2))^2)/0.5);
    end
end
for i=1:Nx,
    rho1(i,1) = 0;
    rho1(i,Nx) = 0;
    rho1(1,i) = 0;
    rho1(Nx,i) = 0;
    rho2(i,1) = 0;
    rho2(i,Nx) = 0;
    rho2(1,i) = 0;
    rho2(Nx,i) = 0;
end

% Normalizing the integral of the initial PDF to 1.
rho1 = rho1/(sum(sum(rho1))*h^2);
rho2 = rho2/(sum(sum(rho2))*h^2);


expname='GaitnPosture';

fname=strcat(expname,'.mat');
load(fname);


% Initial position.
a1 = traj1(0,1);
a2 = traj2(0,1);
a1 = a1.*scale;
a2 = a2.*scale;

X1(1) = a1(1);
Y1(1) = a1(2);
X2(1) = a2(1);
Y2(1) = a2(2);
% Using Euler method for determining trajectory.

for k = 2:Nt
    k;
    X1(k) = X1(k-1) - dt*B_1(t(k-1),x(1),y(1),h,u11_t(k-1),u12_t(k-1))*scale;
    Y1(k) = Y1(k-1) - dt*B_2(t(k-1),x(1),y(1),h,u11_t(k-1),u12_t(k-1))*scale;
    X2(k) = X2(k-1) - dt*B_3(t(k-1),x(1),y(1),h,u21_t(k-1),u22_t(k-1))*scale;
    Y2(k) = Y2(k-1) - dt*B_4(t(k-1),x(1),y(1),h,u21_t(k-1),u22_t(k-1))*scale;
    
end
    
vidname=strcat(expname,'.avi');
vid3 = VideoWriter(vidname);
vid3.FrameRate = 5;
open(vid3);

hfig = figure(1) ;
F1(Nt-1) = struct('cdata',[],'colormap',[]);

if (rho < 1)
    
    for k = 1:Nt
        h = plot(X1(k),Y1(k),'ro', X2(k),Y2(k),'bo');
        if(k ==26)
            set(h(2),'MarkerEdgeColor','none','MarkerFaceColor','k','MarkerSize',10)
            text(X2(k),Y2(k), sprintf('   t=%.2f',t(k)), 'color', 'k')
        else if(mod(k,8)==0)
                
                set(h(1),'MarkerEdgeColor','none','MarkerFaceColor','r','MarkerSize',10)
                text(X1(k),Y1(k), sprintf('   t=%.2f',t(k)), 'color', 'r', 'VerticalAlignment','top')
                set(h(2),'MarkerEdgeColor','none','MarkerFaceColor','b','MarkerSize',10)
                text(X2(k),Y2(k), sprintf('   t=%.2f',t(k)), 'color', 'b')
            end
        end
        xlabel('x')
        ylabel('y')
        hold on
        title('Evolution of the center of the PDF')
        legend('Player A','Player B')
        F1(k) = getframe(hfig);
        writeVideo(vid3,F1(k));
    end
else
    for k = 1:Nt
        h = plot(X1(k),Y1(k),'ro', X2(k),Y2(k),'bo');
        if(k ==28)
            set(h(1),'MarkerEdgeColor','none','MarkerFaceColor','k','MarkerSize',10)
        end
        if(k==26)
            set(h(2),'MarkerEdgeColor','none','MarkerFaceColor','k','MarkerSize',10)
            text(X2(k),Y2(k), sprintf('   t=%.2f',t(k)), 'color', 'k')
        else if(mod(k,8)==0)
                
                set(h(1),'MarkerEdgeColor','none','MarkerFaceColor','r','MarkerSize',10)
                text(X1(k),Y1(k), sprintf('   t=%.2f',t(k)), 'color', 'r', 'VerticalAlignment','top')
                set(h(2),'MarkerEdgeColor','none','MarkerFaceColor','b','MarkerSize',10)
                text(X2(k),Y2(k), sprintf('   t=%.2f',t(k)), 'color', 'b')
            end
        end
        xlabel('x')
        ylabel('y')
        hold on
        title('Evolution of the center of the PDF')
        legend('Player A','Player B')
        F1(k) = getframe(hfig);
        writeVideo(vid3,F1(k));
    end
end

close(vid3);
